<?php
/**
 * Service Section options
 *
 * @package Theme Palace
 * @subpackage  Balen
 * @since  Balen 1.0.0
 */

// Add Service section
$wp_customize->add_section( 'balen_services_section', 
	array(
		'title'             => esc_html__( 'Our Services','balen' ),
		'description'       => esc_html__( 'Our Services Section options.', 'balen' ),
		'panel'             => 'balen_front_page_panel',
	) 
);

// Service content enable control and setting
$wp_customize->add_setting( 'balen_theme_options[services_section_enable]', 
	array(
		'default'			=> 	$options['services_section_enable'],
		'sanitize_callback' => 'balen_sanitize_switch_control',
	) 
);

$wp_customize->add_control( new  Balen_Switch_Control( $wp_customize,
	'balen_theme_options[services_section_enable]', 
		array(
			'label'             => esc_html__( 'Our Services Section Enable', 'balen' ),
			'section'           => 'balen_services_section',
			'on_off_label' 		=> balen_switch_options(),
		) 
	)
);

// services title setting and control
$wp_customize->add_setting( 'balen_theme_options[services_subtitle]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['services_subtitle'],
        'transport'         => 'postMessage',
    )
);

$wp_customize->add_control( 'balen_theme_options[services_subtitle]',
    array(
        'label'             => esc_html__( 'Section Sub Title', 'balen' ),
        'section'           => 'balen_services_section',
        'type'              => 'text',
		'active_callback'	=> 'balen_is_services_section_enable'
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'balen_theme_options[services_subtitle]',
        array(
            'selector'            => '#balen_our_services .section-header p',
            'settings'            => 'balen_theme_options[services_subtitle]',
            'container_inclusive' => false,
            'fallback_refresh'    => true,
            'render_callback'     => 'balen_services_subtitle_partial',
        )
    );
}

// services title setting and control
$wp_customize->add_setting( 'balen_theme_options[services_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['services_title'],
        'transport'         => 'postMessage',
    )
);

$wp_customize->add_control( 'balen_theme_options[services_title]',
    array(
        'label'             => esc_html__( 'Section Title', 'balen' ),
        'section'           => 'balen_services_section',
        'active_callback'   => 'balen_is_services_section_enable',
        'type'              => 'text',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'balen_theme_options[services_title]',
        array(
            'selector'            => '#balen_our_services .section-header h2',
            'settings'            => 'balen_theme_options[services_title]',
            'container_inclusive' => false,
            'fallback_refresh'    => true,
            'render_callback'     => 'balen_services_title_partial',
        )
    );
}

$wp_customize->add_setting( 'balen_theme_options[services_image]',
	array(
		'sanitize_callback' => 'balen_sanitize_image',
	)
);

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize,
	'balen_theme_options[services_image]',
		array(
			'label'       		=> esc_html__( 'Background Image', 'balen' ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'balen' ), 1350, 385 ),
			'section'     		=> 'balen_services_section',
			'active_callback'	=> 'balen_is_services_section_enable',
		)
	)
);


for($i = 1; $i <= $options['services_posts_count']; $i ++):
		
    // service pages drop down chooser control and setting
	$wp_customize->add_setting( 'balen_theme_options[services_content_page_'.$i.']',
		array(
			'sanitize_callback' => 'balen_sanitize_page',
		) 
	);

	$wp_customize->add_control( new  Balen_Dropdown_Chooser( $wp_customize,
		'balen_theme_options[services_content_page_'.$i.']',
			array(
				'label'             => sprintf(esc_html__( 'Select Page : %d', 'balen'), $i ),
				'section'           => 'balen_services_section',
				'choices'			=> balen_page_choices(),
				'active_callback'	=> 'balen_is_services_section_enable',
			) 
		)
	);


    // Balen_Customize_Horizontal_Line
    $wp_customize->add_setting('balen_theme_options[services_separator'. $i .']',
		array(
			'sanitize_callback'      => 'balen_sanitize_html',
		)
	);

    $wp_customize->add_control(new  Balen_Customize_Horizontal_Line($wp_customize,
		'balen_theme_options[services_separator'. $i .']',
			array(
				'active_callback'       => 'balen_is_services_section_enable',
				'type'                  =>'hr',
				'section'               =>'balen_services_section',
			)
		)
	);

endfor;

// Service Excerpt length setting and control.
$wp_customize->add_setting( 'balen_theme_options[services_excerpt_length]',
	array(
		'sanitize_callback' => 'balen_sanitize_number_range',
		'default'			=> $options['services_excerpt_length'],
	)
);

$wp_customize->add_control( 'balen_theme_options[services_excerpt_length]',
	array(
		'label'       		=> esc_html__( 'Excerpt Length', 'balen' ),
		'description' 		=> esc_html__( 'Total words to be displayed in Service section', 'balen' ),
		'section'     		=> 'balen_services_section',
		'type'        		=> 'number',
		'active_callback' 	=> 'balen_is_services_section_enable',
	)
);