<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage  Balen
 * @since  Balen 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function balen_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'balen' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function balen_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'balen' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    wp_reset_postdata();
    return  $choices;
}


/**
 * List of category for category choices.
 * @return Array Array of post ids and name.
 */
function balen_category_choices() {
    $tax_args = array(
        'hierarchical' => 0,
        'taxonomy'     => 'category',
    );
    $taxonomies = get_categories( $tax_args );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'balen' );
    foreach ( $taxonomies as $tax ) {
        $choices[ $tax->term_id ] = $tax->name;
    }
    return  $choices;
}

if ( ! function_exists( 'balen_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function balen_site_layout() {
        $balen_site_layout = array(
            'wide'          => esc_url( get_template_directory_uri() . '/assets/images/full.png' ),
            'frame-layout'  => esc_url( get_template_directory_uri() . '/assets/images/framed.png' ),
        );

        $output = apply_filters( 'balen_site_layout', $balen_site_layout );
        return $output;
    }
endif;

if ( ! function_exists( 'balen_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function balen_selected_sidebar() {
        $balen_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'balen' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'balen' ),
        );

        $output = apply_filters( 'balen_selected_sidebar', $balen_selected_sidebar );

        return $output;
    }
endif;


if ( ! function_exists( 'balen_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function balen_global_sidebar_position() {
        $balen_global_sidebar_position = array(
            'right-sidebar' => esc_url( get_template_directory_uri() . '/assets/images/right.png' ),
            'no-sidebar'    => esc_url( get_template_directory_uri() . '/assets/images/full.png' ),
        );

        $output = apply_filters( 'balen_global_sidebar_position', $balen_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'balen_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function balen_sidebar_position() {
        $balen_sidebar_position = array(
            'right-sidebar'         => esc_url( get_template_directory_uri() . '/assets/images/right.png' ),
            'no-sidebar'            => esc_url( get_template_directory_uri() . '/assets/images/full.png' ),
        );

        $output = apply_filters( 'balen_sidebar_position', $balen_sidebar_position );

        return $output;
    }
endif;

if ( ! function_exists( 'balen_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function balen_pagination_options() {
        $balen_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'balen' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'balen' ),
        );

        $output = apply_filters( 'balen_pagination_options', $balen_pagination_options );

        return $output;
    }
endif;


if ( ! function_exists( 'balen_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function balen_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'balen' ),
            'off'       => esc_html__( 'Disable', 'balen' )
        );
        return apply_filters( 'balen_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'balen_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function balen_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'balen' ),
            'off'       => esc_html__( 'No', 'balen' )
        );
        return apply_filters( 'balen_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'balen_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function balen_sortable_sections() {
        $options = balen_get_theme_options();
  
        $sections = array(
            
            'hero_banner'               => esc_html__( 'Hero Banner', 'balen' ),
            'about_us'                  => esc_html__( 'About us', 'balen' ),
            'services'                  => esc_html__( 'Our Service', 'balen' ),
            'testimonial'               => esc_html__( 'Testimonial', 'balen' ),
            'connect'                   => esc_html__( 'Connect', 'balen' ),
        );
         
        return apply_filters( 'balen_sortable_sections', $sections );
    }
endif;
